@@ -6,6 +6,19 @@ Config::Config(ProximitySensor* ps_, CameraKey* ck_)
 {
 	configDir="/home/user/.shortcutd";
 	configFile="/home/user/.shortcutd/config";
+
+
+	// defaults
+	proximityVibrateOn=1;
+	proximityOn = 0;
+	camerakeyOn = 1;
+	ps_shortPress = "dashboard";
+	ps_longPress = "phone";
+	ps_hold = "disabled";
+	ck_shortPress = "dashboard";
+	ck_longPress = "phone";
+
+
 	input = fopen(configFile,"r");
 	if(input) {
 		init_JSON_config(&config);
@@ -21,14 +34,17 @@ Config::Config(ProximitySensor* ps_, CameraKey* ck_)
 	jc = new_JSON_parser(&config);		    
 	count=0;
 	s_IsKey=0;
-	proximityOn=1;
-	camerakeyOn=1;
+
 	ps=ps_;
 	ck=ck_;
 	
 	me=this;
 }
 
+Config::~Config()
+{
+}
+
 void Config::writeConfigFile()
 {
 	mkdir(configDir, 0755);
@@ -40,15 +56,21 @@ void Config::writeConfigFile()
   	{
 		DebugPrint("creating config file");
     		f << "{\n";
-    		f << "\"proximityOn\": 1,";
+    		f << "\"proximityOn\": " << proximityOn << ",";
 		f << "\n";
-		f << "\"camerakeyOn\": 1,";
+    		f << "\"proximityVibrateOn\": " << proximityVibrateOn << ",";
 		f << "\n";
-		f << "\"proximityShortPress\": \"dashboard\",";
+		f << "\"camerakeyOn\": " << camerakeyOn << ",";
 		f << "\n";
-		f << "\"proximityLongPress\": \"phone\",";
+		f << "\"proximityShortPress\": \"" << ps_shortPress << "\",";
 		f << "\n";
-		f << "\"proximityHold\": \"proximityToggle\"";
+		f << "\"proximityLongPress\": \"" << ps_longPress << "\",";
+		f << "\n";
+		f << "\"proximityHold\": \"" << ps_hold << "\",";
+		f << "\n";
+		f << "\"camerakeyShortPress\": \"" << ck_shortPress << "\",";
+		f << "\n";
+		f << "\"camerakeyLongPress\": \"" << ck_longPress << "\"";
 		f << "\n";
     		f << "}\n";
 		f.close();
@@ -118,7 +140,10 @@ void Config::setInt(int value_)
 	if (key.compare("proximityOn")==0)
 		proximityOn=value_;	
    	 if (key.compare("camerakeyOn")==0)
-        	camerakeyOn=value_;
+		camerakeyOn=value_;
+   	 if (key.compare("proximityVibrateOn")==0)
+		proximityVibrateOn=value_;
+	 
 	
 	DebugPrint("config SET: ");
 	DebugPrint(key);
@@ -129,13 +154,30 @@ void Config::setInt(int value_)
 
 void Config::setString(std::string value_)
 {
-
 	if (key.compare("proximityShortPress")==0)
-		ps->shortPress=value_;
+		ps_shortPress=value_;
 	if (key.compare("proximityLongPress")==0)
-		ps->longPress=value_;
+		ps_longPress=value_;
 	if (key.compare("proximityHold")==0)
-		ps->hold=value_;
+		ps_hold=value_;
+	if (key.compare("camerakeyShortPress")==0)
+		ck_shortPress=value_;
+	if (key.compare("camerakeyLongPress")==0)
+		ck_longPress=value_;
+
+	if( ps != NULL )
+	{
+		ps->shortPress = ps_shortPress;
+		ps->longPress = ps_longPress;
+		ps->hold = ps_hold;
+		ps->vibrateOn=proximityVibrateOn;
+	}
+	if( ck != NULL )
+	{
+		ck->shortPress = ck_shortPress;
+		ck->longPress = ck_longPress;
+	
+	}
 
 	DebugPrint("config SET: ");
 	DebugPrint(key);
