@@ -17,6 +17,7 @@
 #include "proximity.h"
 #include "camkey.h"
 #include "config.h"
+#include "launcher.h"
 #include <fstream>
 #include <iostream>
 #include <glib.h>
@@ -49,9 +50,13 @@ int main(int argc, char** argv)
 
 	ProximitySensor* ps;
 	CameraKey* ck;
-
+	Launcher* launcher=new Launcher();
+	
 	DebugPrint("creating ps");
-	ps = new ProximitySensor;
+	ps = new ProximitySensor(launcher);
+	DebugPrint("...ok");
+	DebugPrint("creating ck");
+	ck = new CameraKey(launcher);
 	DebugPrint("...ok");
 	DebugPrint("reading config");
 	Config* conf = new Config(ps,ck);
@@ -68,9 +73,6 @@ int main(int argc, char** argv)
 		DebugPrint("proximity sensor disabled");
 	}
 	
-	DebugPrint("creating ck");
-	ck = new CameraKey;
-	DebugPrint("...ok");
 
 	if( conf->camerakeyOn==1 )
 	{	
